# DarkSearch

[![PyPI](https://img.shields.io/pypi/v/darksearch?color=orange&logo=pypi&logoColor=orange)](https://pypi.org/project/darksearch/)
[![Python Version](https://img.shields.io/badge/python-3.6%2B-blue?logo=python)](https://www.python.org/downloads/)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/thehappydinoa/DarkSearch/test?label=tests)](https://github.com/thehappydinoa/DarkSearch/actions)
[![Read the Docs](https://img.shields.io/readthedocs/darksearch/latest)](https://censys-python.readthedocs.io/en/stable/?badge=stable)
[![License](https://img.shields.io/github/license/thehappydinoa/DarkSearch)](LICENSE)

Python API wrapper for DarkSearch ([darksearch.io](https://darksearch.io/)). Python 3.6+ is currently supported.

## Install

```bash
pip install darksearch
```

## Resources

- [Documentation](https://darksearch.readthedocs.io/)

## Contributing

All contributions (no matter how small) are always welcome.

## Development

```bash
git clone git@github.com:thehappydinoa/DarkSearch.git
poetry install
```

## Testing

```bash
pytest
```

## Publishing

```bash
poetry build
poetry publish
```

## License

This software is licensed under [MIT](LICENSE)
